@@ -1,20 +1,16 @@
 package URI::Namespace;
-use strict;
-use warnings;
-
 use Moo 1.006000;
 use URI;
 use IRI 0.003;
 use Types::Namespace 0.004 qw( Iri );
 use namespace::autoclean;
 
-our $VERSION = '0.32';
+our $VERSION = '1.00';
 
 =head1 NAME
 
 URI::Namespace - A namespace URI/IRI class with autoload methods
 
-
 =head1 SYNOPSIS
 
   use URI::Namespace;
